pub struct Descriptor {
pub nodes: Vec<Node>,
pub env: Option<BTreeMap<String, EnvValue>>,
pub communication: CommunicationConfig,
pub deploy: Option<Deploy>,
pub debug: Debug,
}Expand description
Dataflow Specification
The main configuration structure for defining a Dora dataflow. Dataflows are specified through YAML files that describe the nodes, their connections, and execution parameters.
Structure
A dataflow consists of:
- Nodes: The computational units that process data
- Communication: Optional communication configuration
- Deployment: Optional deployment configuration (unstable)
- Debug options: Optional development and debugging settings (unstable)
Example
nodes:
- id: webcam
operator:
python: webcam.py
inputs:
tick: dora/timer/millis/100
outputs:
- image
- id: plot
operator:
python: plot.py
inputs:
image: webcam/imageFields
nodes: Vec<Node>List of nodes in the dataflow
This is the most important field of the dataflow specification.
Each node must be identified by a unique id:
Example
nodes:
- id: foo
path: path/to/the/executable
# ... (see below)
- id: bar
path: path/to/another/executable
# ... (see below)For each node, you need to specify the path of the executable or script that Dora should run when starting the node.
Most of the other node fields are optional, but you typically want to specify at least some inputs and/or outputs.
env: Option<BTreeMap<String, EnvValue>>Global Environment variables inherited by all nodes (optional)
Example
env:
MY_VAR: "my_var"
nodes:
- id: foo
path: path/to/the/executable
# ... (see below)
- id: bar
path: path/to/another/executable
# ... (see below)Note that, If there is an env at the node level, Node level env will have more priority than the global env
communication: CommunicationConfigCommunication configuration (optional, uses defaults)
deploy: Option<Deploy>Deployment configuration (optional, unstable)
debug: DebugDebug options (optional, unstable)